@@ -32,20 +32,19 @@ import java.nio.charset.StandardCharsets;
 import java.util.Properties;
 
 import static org.mockito.ArgumentMatchers.any;
-import static org.mockito.ArgumentMatchers.anyLong;
-import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.when;
 
-/** test for DorisStreamLoad. */
+/**
+ * test for DorisStreamLoad.
+ */
 public class TestDorisStreamLoad {
     DorisOptions dorisOptions;
     DorisReadOptions readOptions;
     DorisExecutionOptions executionOptions;
 
     @Before
-    public void setUp() throws Exception {
+    public void setUp() throws Exception{
         dorisOptions = OptionUtils.buildDorisOptions();
         readOptions = OptionUtils.buildDorisReadOptions();
         executionOptions = OptionUtils.buildExecutionOptional();
@@ -54,73 +53,24 @@ public class TestDorisStreamLoad {
     @Test
     public void testAbortPreCommit() throws Exception {
         CloseableHttpClient httpClient = mock(CloseableHttpClient.class);
-        CloseableHttpResponse existLabelResponse =
-                HttpTestUtil.getResponse(HttpTestUtil.LABEL_EXIST_PRE_COMMIT_TABLE_RESPONSE, true);
-        CloseableHttpResponse preCommitResponse =
-                HttpTestUtil.getResponse(HttpTestUtil.PRE_COMMIT_TABLE_RESPONSE, true);
-        when(httpClient.execute(any())).thenReturn(existLabelResponse, preCommitResponse);
-        DorisStreamLoad dorisStreamLoad =
-                spy(
-                        new DorisStreamLoad(
-                                "",
-                                dorisOptions,
-                                executionOptions,
-                                new LabelGenerator("test001", true, "db.table", 0),
-                                httpClient));
-
-        doNothing().when(dorisStreamLoad).abortTransaction(anyLong());
-        dorisStreamLoad.abortPreCommit("test001", 1);
+        CloseableHttpResponse existLabelResponse = HttpTestUtil.getResponse(HttpTestUtil.LABEL_EXIST_PRE_COMMIT_RESPONSE, true);
+        CloseableHttpResponse abortSuccessResponse = HttpTestUtil.getResponse(HttpTestUtil.ABORT_SUCCESS_RESPONSE, true);
+        CloseableHttpResponse preCommitResponse = HttpTestUtil.getResponse(HttpTestUtil.PRE_COMMIT_RESPONSE, true);
+        when(httpClient.execute(any())).thenReturn(existLabelResponse, abortSuccessResponse, preCommitResponse);
+        DorisStreamLoad dorisStreamLoad = new DorisStreamLoad("", dorisOptions, executionOptions, new LabelGenerator("test001_0", true), httpClient);
+        dorisStreamLoad.abortPreCommit("test001_0", 1);
     }
 
     @Test
-    public void testAbortTransaction() throws Exception {
+    public void testWriteOneRecordInCsv() throws Exception{
         CloseableHttpClient httpClient = mock(CloseableHttpClient.class);
-        CloseableHttpResponse abortSuccessResponse =
-                HttpTestUtil.getResponse(HttpTestUtil.ABORT_SUCCESS_RESPONSE, true);
-        when(httpClient.execute(any())).thenReturn(abortSuccessResponse);
-        DorisStreamLoad dorisStreamLoad =
-                new DorisStreamLoad(
-                        "",
-                        dorisOptions,
-                        executionOptions,
-                        new LabelGenerator("test001", true),
-                        httpClient);
-        dorisStreamLoad.abortTransaction(anyLong());
-    }
-
-    @Test
-    public void testAbortTransactionFailed() throws Exception {
-        CloseableHttpClient httpClient = mock(CloseableHttpClient.class);
-        CloseableHttpResponse abortFailedResponse =
-                HttpTestUtil.getResponse(HttpTestUtil.ABORT_FAILED_RESPONSE, true);
-        when(httpClient.execute(any())).thenReturn(abortFailedResponse);
-        DorisStreamLoad dorisStreamLoad =
-                new DorisStreamLoad(
-                        "",
-                        dorisOptions,
-                        executionOptions,
-                        new LabelGenerator("test001", true),
-                        httpClient);
-        dorisStreamLoad.abortTransaction(anyLong());
-    }
-
-    @Test
-    public void testWriteOneRecordInCsv() throws Exception {
-        CloseableHttpClient httpClient = mock(CloseableHttpClient.class);
-        CloseableHttpResponse preCommitResponse =
-                HttpTestUtil.getResponse(HttpTestUtil.PRE_COMMIT_RESPONSE, true);
+        CloseableHttpResponse preCommitResponse = HttpTestUtil.getResponse(HttpTestUtil.PRE_COMMIT_RESPONSE, true);
         when(httpClient.execute(any())).thenReturn(preCommitResponse);
         byte[] writeBuffer = "test".getBytes(StandardCharsets.UTF_8);
-        DorisStreamLoad dorisStreamLoad =
-                new DorisStreamLoad(
-                        "",
-                        dorisOptions,
-                        executionOptions,
-                        new LabelGenerator("", true),
-                        httpClient);
-        dorisStreamLoad.startLoad("1", false);
+        DorisStreamLoad dorisStreamLoad = new DorisStreamLoad("", dorisOptions, executionOptions, new LabelGenerator("", true), httpClient);
+        dorisStreamLoad.startLoad("1");
         dorisStreamLoad.writeRecord(writeBuffer);
-        dorisStreamLoad.stopLoad("label");
+        dorisStreamLoad.stopLoad();
         byte[] buff = new byte[4];
         int n = dorisStreamLoad.getRecordStream().read(buff);
         dorisStreamLoad.getRecordStream().read(new byte[4]);
@@ -130,24 +80,17 @@ public class TestDorisStreamLoad {
     }
 
     @Test
-    public void testWriteTwoRecordInCsv() throws Exception {
+    public void testWriteTwoRecordInCsv() throws Exception{
         executionOptions = OptionUtils.buildExecutionOptional();
         CloseableHttpClient httpClient = mock(CloseableHttpClient.class);
-        CloseableHttpResponse preCommitResponse =
-                HttpTestUtil.getResponse(HttpTestUtil.PRE_COMMIT_RESPONSE, true);
+        CloseableHttpResponse preCommitResponse = HttpTestUtil.getResponse(HttpTestUtil.PRE_COMMIT_RESPONSE, true);
         when(httpClient.execute(any())).thenReturn(preCommitResponse);
         byte[] writeBuffer = "test".getBytes(StandardCharsets.UTF_8);
-        DorisStreamLoad dorisStreamLoad =
-                new DorisStreamLoad(
-                        "",
-                        dorisOptions,
-                        executionOptions,
-                        new LabelGenerator("", true),
-                        httpClient);
-        dorisStreamLoad.startLoad("1", false);
+        DorisStreamLoad dorisStreamLoad = new DorisStreamLoad("", dorisOptions, executionOptions, new LabelGenerator("", true), httpClient);
+        dorisStreamLoad.startLoad("1");
         dorisStreamLoad.writeRecord(writeBuffer);
         dorisStreamLoad.writeRecord(writeBuffer);
-        dorisStreamLoad.stopLoad("label");
+        dorisStreamLoad.stopLoad();
         byte[] buff = new byte[9];
         int n = dorisStreamLoad.getRecordStream().read(buff);
         int ret = dorisStreamLoad.getRecordStream().read(new byte[9]);
@@ -157,7 +100,7 @@ public class TestDorisStreamLoad {
     }
 
     @Test
-    public void testWriteTwoRecordInJson() throws Exception {
+    public void testWriteTwoRecordInJson() throws Exception{
         Properties properties = new Properties();
         properties.setProperty("column_separator", "|");
         properties.setProperty("line_delimiter", "\n");
@@ -165,21 +108,14 @@ public class TestDorisStreamLoad {
         executionOptions = OptionUtils.buildExecutionOptional(properties);
         byte[] expectBuffer = "{\"id\": 1}\n{\"id\": 2}".getBytes(StandardCharsets.UTF_8);
         CloseableHttpClient httpClient = mock(CloseableHttpClient.class);
-        CloseableHttpResponse preCommitResponse =
-                HttpTestUtil.getResponse(HttpTestUtil.PRE_COMMIT_RESPONSE, true);
+        CloseableHttpResponse preCommitResponse = HttpTestUtil.getResponse(HttpTestUtil.PRE_COMMIT_RESPONSE, true);
         when(httpClient.execute(any())).thenReturn(preCommitResponse);
 
-        DorisStreamLoad dorisStreamLoad =
-                new DorisStreamLoad(
-                        "",
-                        dorisOptions,
-                        executionOptions,
-                        new LabelGenerator("", true),
-                        httpClient);
-        dorisStreamLoad.startLoad("1", false);
+        DorisStreamLoad dorisStreamLoad = new DorisStreamLoad("", dorisOptions, executionOptions, new LabelGenerator("", true), httpClient);
+        dorisStreamLoad.startLoad("1");
         dorisStreamLoad.writeRecord("{\"id\": 1}".getBytes(StandardCharsets.UTF_8));
         dorisStreamLoad.writeRecord("{\"id\": 2}".getBytes(StandardCharsets.UTF_8));
-        dorisStreamLoad.stopLoad("label");
+        dorisStreamLoad.stopLoad();
         byte[] buff = new byte[expectBuffer.length];
         int n = dorisStreamLoad.getRecordStream().read(buff);
 
